/** \file
 * Header for the CAtlExtStorage interface
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */

#ifndef CAtlExtStorage_h
#define CAtlExtStorage_h


// We use this namespace for our library.
namespace  AvAtl {

// Forward declarations.
class CAtlMgr;
class CAtlVector;
class CAtlPolygon;


/// External storage of points and polygons support
/** \interface CAtlExtStorage 
 *	Inherit from CAtlExtStorage allows you to store a list of points and a list of polygons yourself.
 * This will help you not to duplicate this heavy information.
 * Usage of this interface is optional.
 * The CAtlMgr passed in all functions is for reference only... dont change or presume of any values.
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */
class CAtlExtStorage
{
public:
	// Internal component support

	/// Set the current internal component instance to be read or write.
	/** Return false to cancel IO. */
	virtual bool	setCurrentInternalComponentInstance(CAtlMgr* inMgr, tUUID inId, unsigned int inGeometryLevel) throw() = 0;

	// Reading Functions called while reading a document.

	/// Indicates the number of points to be read.
	virtual void	setNbPoints(CAtlMgr* inMgr, int inNbPoints) throw() = 0;

	/// Process this read point.
	/** Return false to cancel IO. */
	virtual bool	takePoint(CAtlMgr* inMgr, const CAtlVector& inPoint, int inIndex) throw() = 0;

	/// Indicates the number of polygons to be read.
	virtual void	setNbPolygons(CAtlMgr* inMgr, int inNbPolys) throw() = 0;

	/// Process this read polygon.
	/** Return false to cancel IO. */
	virtual bool	takePolygon(CAtlMgr* inMgr, CAtlPolygon& inPolygon, int inIndex) throw() = 0;

	// Writing Functions called while writing a document.

	/// Here you must return the number of points to be saved.
	virtual int		getNbPoints(CAtlMgr* inMgr) throw() = 0;

	/// Fill the point indexed by i.
	/** Return false to cancel IO. */
	virtual bool	fillPoint(CAtlMgr* inMgr, CAtlVector* outPoint, int inIndex) throw() = 0;

	/// Here you must return the number of polygons to be saved.
	virtual int		getNbPolygons(CAtlMgr* inMgr) throw() = 0;

	/// Fill the polygon indexed by i.
	/** Return false to cancel IO. */
	virtual bool	fillPolygon(CAtlMgr* inMgr, CAtlPolygon* outPolygon, int inIndex) throw() = 0;
};

} //end namespace

#endif
