/*!
	\file	IAtl3DPAth.h
	\author	Abvent R&D Copyright (C) 2006
	\author	Guillaume Boulet-Gercourt
	\date	10 02 2006
	\brief	Header for the IAtl3DPath interface
*/
#ifndef	IAtl3DPath_h
#define	IAtl3DPath_h

// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif
#ifndef	IAtlBezierPoint_h
	#include "IAtlBezierPoint.h"
#endif

namespace AvAtl {


/// Manager of instances
typedef TAtlObjectMgr<class IAtl3DPath>	Atl3DPathsMgr;

/*!
	\interface	IAtl3DPath
	\author		Abvent R&D Copyright (C) 2006
	\author		Guillaume Boulet-Gercourt
	\date		10 02 2006
	\brief		Describes the geometric entity of a spline.
*/
class	IAtl3DPath
{
public:
	/// get this path's identifier
	virtual tUUID		getId() const = 0;
	/// set this path's identifier
	virtual void		setId(tUUID inId) = 0;

	/// get the closed flag
	virtual bool		getClosed() const = 0;
	/// set the closed flag
	virtual void		setClosed(bool inClosed) = 0;

	/// get the list of control point
	/** For consulting **/
	virtual const AtlBezierPointsMgr*	getBezierPointsMgr() const = 0;
	/// get the list of control point
	/** For editing */
	virtual AtlBezierPointsMgr*			getBezierPointsMgr() = 0;

	/// Put an XML representation of the path inside the father node.
	/** \retval the new node of the key frame.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the path with the XML.
	/** \retval true initialisation from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~IAtl3DPath() {}
};


} // namespace AvAtl


#endif // IAtl3DPath_h
