/*!
	\file	IAtl3DPlantRef.h
	\author Abvent R&D Copyright 2004
	\author Guillaume Boulet-Gercourt
	\date 16/04/2004
	\brief Definition of IAtl3DPlantRef interface
*/
#ifndef		IAtl3DPlantRef_h
# define	IAtl3DPlantRef_h

// Basic class.
#ifndef AtlTypes_h
	#include	"AvAtlTypes.h"
#endif
#ifndef	IAtl3DPlant_h
	#include	"IAtl3DPlant.h"
#endif
#ifndef CAtlTime_h
	#include	"CAtlTime.h"
#endif

// We use this namespace for our library.
namespace AvAtl {


// Forward declaration
class IAtlObjectInstance;


/*!
	\addtogroup Atl Objects
	\{
*/


/// Interface for atl 3d plants references
/** \interface IAtl3DPlantRef 
*	Interface that represent atl 3d plants reference
*
* \author Abvent R&D Copyright (c) 2004
* \author Guillaume Boulet-Gercourt
* \version 1.0
* \date 16/04/2004
*/
class IAtl3DPlantRef
{
public:	//! Get the attached heliodon name
	/// Type conversion to IAtlObjectInstance
	virtual const IAtlObjectInstance*	asObjectInstance() const = 0;

	/// Type conversion to IAtlObjectInstance
	virtual IAtlObjectInstance*			asObjectInstance() = 0;

	//! Check if the plant is attached to the current heliodon
	virtual bool					getUsedHeliodon() const = 0;
	//! attach or detach a plant to the current heliodon
	virtual void					setUsedHeliodon(bool inUsed) = 0;

	//! return the current time (for consulting)
	virtual const CAtlTime&			getCurrentTime() const = 0;
	//! return the current time (for editing)
	virtual CAtlTime&				getCurrentTime() = 0;

	//! Get the current color of this plant
	virtual IAtl3DPlant::eColor		getCurrentColor(void) const = 0;
	//! Set the current color of this plant
	virtual void					setCurrentColor(IAtl3DPlant::eColor inColor) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class. */
	virtual							~IAtl3DPlantRef() {}
private:
};

/*!
	\} // group Atl Objects
*/

}		// namespace AvAtl

#endif		// IAtlObjectRef_h
