/*!
	\file	IAtlBackgroundPicture.h
	\author	Abvent R&D Copyright (C) 2006
	\author	Guillaume Boulet-Gercourt
	\date	18 09 2006
	\brief	Header for the IAtlBackgroundPicture interface
*/
#ifndef	IAtlBackgroundPicture_h
#define	IAtlBackgroundPicture_h

// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef	CAtlColor_h
	#include "CAtlColor.h"
#endif

namespace AvAtl {

/*!
	\interface IAtlBackgroundPicture
	\author	Abvent R&D Copyright (C) 2006
	\author	Guillaume Boulet-Gercourt
	\date	18 09 2006
	\brief	describes a new Background in the ATL format.
	This class describes new Background of the ATL format, since the 2.2 version of atl library
*/
class	IAtlBackgroundPicture
{
public:

	/*! \enum eBackgroundType 
		all kind of backgrounds
	*/
	enum	eBackgroundType
	{
		kNone = 0,
		kUserGradiant,
		k2DPicture,
		k3DMovie,
		kHDRI
	};

	/// Get the kind of the background
	virtual eBackgroundType					getType() const = 0;
	/// Set the kind of the background
	virtual void							setType(eBackgroundType inType) = 0;

	/// Get the url of the picture
	virtual tURL							getURL() const = 0;
	/// Set the url of the picture
	virtual void							setURL(tURL inURL) = 0;

	/// Get the "3D" flag
	virtual bool							get3DFlag() const = 0;
	/// Set the "3D" flag
	virtual void							set3DFlag(bool inFlag) = 0;

	/// Get the first color of background
	virtual const CAtlColor&				getFirstColor() const = 0;
	/// Set the first color of background
	virtual void							setFirstColor(const CAtlColor& inColor) = 0;

	/// Get the second color of background
	virtual const CAtlColor&				getSecondColor() const = 0;
	/// Set the second color of background
	virtual void							setSecondColor(const CAtlColor& inColor) = 0;

	/// Get the third color of background
	virtual const CAtlColor&				getThirdColor() const = 0;
	/// Set the third color of background
	virtual void							setThirdColor(const CAtlColor& inColor) = 0;

	/// Get the horizontal offset of background
	virtual double							getHOffset() const = 0;
	/// Set the horizontal offset of background
	virtual void							setHOffset(double inValue) = 0;

	/// Get the vertical offset of background
	virtual double							getVOffset() const = 0;
	/// Set the vertical offset of background
	virtual void							setVOffset(double inValue) = 0;

	/// Put an XML representation of the background inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef						putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the background with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool							initWithXML(XMLNodeRef inFatherNode) = 0;

	/// Get the lighting flag of the hdri backgroud
	virtual bool							getActiveLightingFlag() const = 0;
	/// Set the lighting flag of the hdri background
	virtual void							setActiveLightingFlag(bool inActive) = 0;

	/// Get the power of lighting for the hdri background
	virtual double								getLightingPower() const = 0;
	/// Set the power of lighting for the hdri background
	virtual void							setLightingPower(double inPower) = 0;

	/// get the hdri background intensity
	virtual double								getBackgroundIntensity() const = 0;
	/// set the hdri background intensity
	virtual void							setBackgroundIntensity(double inPower) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class.  */
	virtual							~IAtlBackgroundPicture() {}
};

} // namespace AvAtl

#endif
