/*!
	\file	IAtlBezierPoint.h
	\author	Abvent R&D Copyright (C) 2006
	\author	Guillaume Boulet-Gercourt
	\date	10 02 2006
	\brief	Header for the IAtlBezierPoint interface
*/
#ifndef	IAtlBezierPoint_h
#define	IAtlBezierPoint_h

// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif
#ifndef	CAtlVector_h
	#include "CAtlVector.h"
#endif

namespace AvAtl {

/// List of control points
typedef TAtlObjectMgr<class IAtlBezierPoint>	AtlBezierPointsMgr;

class IAtlBezierPoint
{
public:
	/// get / set the position of point
	virtual const CAtlVector&	getPosition() const = 0;
	virtual void				setPosition(const CAtlVector& inPoint) = 0;

	virtual	const CAtlVector&	getBeforeCtrlPt() const = 0;
	virtual	void				setBeforeCtrlPt(const CAtlVector& inPoint) = 0;

	virtual	const CAtlVector&	getAfterCtrlPt() const = 0;
	virtual	void				setAfterCtrlPt(const CAtlVector& inPoint) = 0;

	virtual	bool				getTangentLocked() const = 0;
	virtual	void				setTangentLocked(bool inLocked) = 0;

	/// Put an XML representation of the bezier point inside the father node.
	/** \retval the new node of the key frame.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the bezier point with the XML.
	/** \retval true initialisation from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;
protected:
	virtual ~IAtlBezierPoint() {}
private:
};


} // namespace AvAtl


#endif // IAtlBezierPoint_h