/*!
	\file	IAtlClouds.h
	\author	Abvent R&D Copyright (C) 2006
	\author	Guillaume Boulet-Gercourt
	\date	18 09 2006
	\brief	Header for the IAtlClouds interface
*/
#ifndef	IAtlClouds_h
#define	IAtlClouds_h

#include "CATL/AvAtlTypes.h"
#include "CATL/CAtlVector.h"

namespace AvAtl {

/*!
	\interface IAtlClouds
	\author	Abvent R&D Copyright (C) 2006
	\author	Guillaume Boulet-Gercourt
	\date	18 09 2006
	\brief	describes a Clouds in the ATL format.

	There are 4 kind of clouds : Cumulus, Cirrus, Stratus, Cirrocumulus
*/
class	IAtlClouds
{
public:
	/// Get active flag
	virtual bool					getActiveFlag() const = 0;
	/// Set active flag
	virtual void					setActiveFlag(bool inFlag) = 0;

	/// Get the Cumulus size
	virtual double					getCumulusSize() const = 0;
	/// Set the Cumulus size
	virtual void					setCumulusSize(double inSize) = 0;

	/// Get the Cumulus random Seed
	virtual int						getCumulusRandomSeed() const = 0;
	/// Set the Cumulus random Seed
	virtual void					setCumulusRandomSeed(int inSeed) = 0;

	/// Get the Cirrus size
	virtual double					getCirrusSize() const = 0;
	/// Set the Cirrus size
	virtual void					setCirrusSize(double inSize) = 0;

	/// Get the Cirrus random Seed
	virtual int						getCirrusRandomSeed() const = 0;
	/// Set the Cirrus random Seed
	virtual void					setCirrusRandomSeed(int inSeed) = 0;

	/// Get the Stratus size
	virtual double					getStratusSize() const = 0;
	/// Set the Stratus size
	virtual void					setStratusSize(double inSize) = 0;

	/// Get the Stratus random Seed
	virtual int						getStratusRandomSeed() const = 0;
	/// Set the Stratus random Seed
	virtual void					setStratusRandomSeed(int inSeed) = 0;

	/// Get the Cirrocumulus size
	virtual double					getCirrocumulusSize() const = 0;
	/// Set the Cirrocumulus size
	virtual void					setCirrocumulusSize(double inSize) = 0;

	/// Get the Cirrocumulus random Seed
	virtual int						getCirrocumulusRandomSeed() const = 0;
	/// Set the Cirrocumulus random Seed
	virtual void					setCirrocumulusRandomSeed(int inSeed) = 0;

	/// Put an XML representation of the background inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the background with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;
protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class.  */
	virtual							~IAtlClouds() {}
	
public: 
	/// Get windy condiftion flag (false by default)
	virtual bool					getActiveWind() const = 0;
	/// Set active flag
	virtual void					setActiveWind(bool inWind) = 0;
	
	/// Get wind speed. Default value is 01.0 kn (knot, equal to one nautical mile per hour, one nautical mile = 1,852.0 m)
	virtual double					getSpeed() const = 0;
	/// Set the  wind speed
	virtual void					setSpeed(double inSpeed) = 0;
	
	/// Return as a vector the wind direction. Default 0.0. Relative to the heliodon north angle..
	virtual double					getDirection() const = 0;
	/// Set the wind direction. 
	virtual void					setDirection(double inAngle) = 0;
	
	/// set the cloud animation current time. Default value 0.
	virtual double					getTime() const = 0;
	/// Set the cloud animation current time.
	virtual void					setTime(double inTime) = 0;
	

};

} // namespace AvAtl

#endif
