/** \file
 * Header for the interface IAtlCompressionOpt
 *
 * \author Abvent R&D Copyright (c) 2000
 * \author Richard Young
 * \version 1.0
 * \date 03/07/2000
 */

#ifndef IAtlCompressionOpt_h
#define IAtlCompressionOpt_h


#ifndef AtlTypes_h
#include "CATL/AvAtlTypes.h"
#endif


namespace  AvAtl {


/// Interface for view compression options.
/** \interface IAtlCompressionOpt 
 *	Class that contains compression options.
 *
 * \author Abvent R&D Copyright (c) 2000
 * \author Richard Young
 * \version 1.0
 * \date 03/07/2000
 */
class IAtlCompressionOpt
{
public:
	// Codec. OS dependent (QuickTime, AVI).
	// Value defined by dialog with user.
	virtual int					getCodec() const = 0;
	virtual void				setCodec(int codec) = 0;

	// Compression depth of the image. OS dependent (QuickTime, AVI).
	// Value defined by dialog with user.
	virtual int					getDepth() const = 0;
	virtual void				setDepth(int depth) = 0;

	// Compression Spacial Quality. OS dependent (QuickTime, AVI).
	// Value defined by dialog with user.
	virtual int					getSpacialQuality() const = 0;
	virtual void				setSpacialQuality(int quality) = 0;

	// Compression Temporal Quality (QuickTime).
	// Value defined by dialog with user.
	virtual int					getTemporalQuality() const = 0;
	virtual void				setTemporalQuality(int quality) = 0;

	// Number of frame by seconds. OS dependent (QuickTime, AVI).
	// Value defined by dialog with user.
	virtual double				getFrameRate() const = 0;
	virtual void				setFrameRate(double framerate) = 0;

	// Number of key frame. OS dependent (QuickTime, AVI).
	// Value defined by dialog with user.
	virtual int					getKeyFrameRate() const = 0;
	virtual void				setKeyFrameRate(int kframerate) = 0;

protected:
	// You must not create or delete objects of this class.
	// This is the responsability of the CAtlMgr class.
								~IAtlCompressionOpt() {}
};


} // namespace AvAtl

#endif
