/*!
	\file	IAtlFog.h
	\author	Abvent R&D Copyright (C) 2006
	\author	Guillaume Boulet-Gercourt
	\date	18 09 2006
	\brief	Header for the IAtlFog interface
*/
#ifndef	IAtlFog_h
#define	IAtlFog_h

// Basic class.
#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef	CAtlColor_h
	#include "CAtlColor.h"
#endif

namespace AvAtl {

/*!
	\interface IAtlFog
	\author	Abvent R&D Copyright (C) 2006
	\author	Guillaume Boulet-Gercourt
	\date	18 09 2006
	\brief	describes a Fog in the ATL format.
*/
class	IAtlFog
{
public:
	/// Get active flag
	virtual bool					getActiveFlag() const = 0;
	/// Set active flag
	virtual void					setActiveFlag(bool inFlag) = 0;

	/// Get the color of fog
	virtual const CAtlColor&		getColor() const = 0;
	/// Set the color of fog
	virtual void					setColor(const CAtlColor& inColor) = 0;

	/// Get the density of fog
	virtual double					getDensity() const = 0;
	/// Set the density of fog
	virtual void					setDensity(double inDensity) = 0;

	/// Get the start distance
	virtual double					getStartDistance() const = 0;
	/// Set the start distance
	virtual void					setStartDistance(double inDistance) = 0;

	/// Get the end distance
	virtual double					getEndDistance() const = 0;
	/// Set the end distance
	virtual void					setEndDistance(double inDistance) = 0;
	
	// End of 2.0 API
	/// Get the altitude of fog (from ground level, top of the fog)
	virtual double					getAltitude() const = 0;
	/// Set the altitude of fog (cm)
	virtual void					setAltitude(double inAltitude) = 0;
	
	// End of 3.0 API

	/// Put an XML representation of the background inside the father node.
	/** \retval the new node of the ambient.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the background with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;

protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class.  */
	virtual							~IAtlFog() {}
};

} // namespace AvAtl

#endif
