/** \file
 * Header for the IAtlPanoNodeV2 interface
 *
 * \author Abvent R&D Copyright (c) 2011
 * \author Christophe
 * \date 18/02/2011
 */

#ifndef IAtlPanoNodeV2_h
#define IAtlPanoNodeV2_h

#ifndef AtlTypes_h
	#include "AvAtlTypes.h"
#endif
#ifndef TAtlObjectMgr_h
	#include "TAtlObjectMgr.h"
#endif
#ifndef CAtlVector_h
	#include "CAtlVector.h"
#endif
#ifndef IAtlPanoLinkV2_h
	#include "IAtlPanoLinkV2.h"
#endif



// We use this namespace for our library.
namespace  AvAtl {

/// List of panorama links
typedef TAtlObjectMgr<class IAtlPanoNodeV2>	AtlPanoNodeV2Mgr;
typedef TAtlObjectMgr<class IAtlPanoramaV2>	AtlPanoramaV2Mgr;
	
/// Information on panorama camera
/** \interface IAtlPanoNodeV2
 *	The information on a panorama
 *
 * \author Abvent R&D Copyright (c) 2011
 * \author Christophe
 * \date 18/02/2011
 */
class IAtlPanoNodeV2
{
protected:
	/** You must not create or delete objects of this class.
	    This is the responsibility of the CAtlMgr class.*/
	virtual							~IAtlPanoNodeV2() {}

public:
	/// Put an XML representation of the panorama inside the father node.
	/** \retval the new node of the panorama.
		\retval NULL if an error occurs. */
	virtual XMLNodeRef				putInXML(XMLNodeRef inFatherNode) const = 0;
	/// Initialize the panorama with the XML.
	/** \retval true intialization from XML succeed.
		\retval false an error occurs. */
	virtual bool					initWithXML(XMLNodeRef inFatherNode) = 0;

	/// Return the name of the panorama.
	/** Do not delete this string. */
	virtual tUtf8					getName() const = 0;
	/// Set the name of the panorama.
	virtual void					setName(tUtf8 inName) = 0;
	
	/// Get the position of this panorama.
	virtual CAtlVector				getPosition() const = 0;
	/// Set the position of this panorama.
	virtual void					setPosition(const CAtlVector& inPosition) = 0;

	/// Return the id of the node
	virtual tUUID					getId() const = 0;
	/// Set the id of the node
	virtual void					setId(tUUID inId) = 0;
};


} // namespace  AvAtl

#endif
