/** \file
 * Header for the IAtlSkylight interface - Public
 *
 * \author Abvent R&D Copyright (c) 2004
 * \author Thomas Donel
 * \version 1.0
 * \date 21/05/2004
 */

#ifndef IAtlSkylight_h
#define IAtlSkylight_h


#ifndef CAtlColor_h
	#include "CAtlColor.h"
#endif


// We use this namespace for our library.
namespace  AvAtl {


// We make our enums int, so you don't have to change your project settings.
#ifdef __MWERKS__
#pragma enumsalwaysint on
#endif


/** \interface IAtlSkylight 
 *	Specify the skylight controls
 *
 * \author Abvent R&D Copyright (c) 2004
 * \author Thomas Donel
 * \version 1.0
 * \date 21/05/2004
 */


class IAtlSkylight
{
public:

	/// Control if the skylight is activated.
	virtual bool					getFlag() const = 0;
	/// Set if the skylight is activated.
	virtual void					setFlag(bool inFlag) = 0;

	/// Return the skylight factor.
	virtual double					getFactor() const = 0;
	/// Set the skylight factor.
	virtual void					setFactor(double inFactor) = 0;

	/// Return the skylight color.
	virtual const CAtlColor&		getColor() const = 0;
	/// Set the skylight color.
	virtual void					setColor(const CAtlColor& inColor) = 0;

	/// End of API V2

	/*! \enum	eSkyType
		\brief	Kind of sky
	*/
	enum eSkyType
	{
		kAutomaticColor = 0,				// automatic color
		kUserLightingColor = 1				// User Color. --> use the "getColor" of the skylight
	};

	/// get the sky type
	virtual eSkyType		getSkyType() const = 0;
	/// set the sky type
	virtual void			setSkyType(eSkyType inType) = 0;

	/// get if the skylight is used as a background
	virtual bool			getUsedAsBackground() const = 0;
	/// set it the skylight is used a a background
	virtual void			setUsedAsBackground(bool inUsed) = 0;

	/// get the pollution of the sky
	virtual double			getPollution() const = 0;
	/// set the pollution of the sky
	virtual void			setPollution(double inPollution) = 0;
	
	/// new for Artlantis 2007
	
	/// Control if the sky mix color is activated.
	virtual bool					getSkyMixColorFlag() const = 0;
	/// Set if the sky mix color is activated.
	virtual void					setSkyMixColorFlag(bool inFlag) = 0;
	/// Return the sky mix color.
	virtual const CAtlColor&		getSkyMixColor() const = 0;
	/// Set the sky mix color.
	virtual void					setSkyMixColor(const CAtlColor& inColor) = 0;
	
	/// Control if the power is activated.
	virtual bool					getPowerFlag() const = 0;
	/// Set if the power is activated.
	virtual void					setPowerFlag(bool inFlag) = 0;

	/// Control if the custom sky color is activated
	virtual bool					getCustomColorFlag() const = 0;
	/// Set if the custom color is activated
	virtual void					setCustomColorFlag(bool inFlag) = 0;
	
	/// new for Artlantis 2007
	
	/// End of API V3
};


#ifdef __MWERKS__
#pragma enumsalwaysint reset
#endif


} // namespace  AvAtl

#endif


