/** \file
 * Header for the interface IAtlTexture
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */

#ifndef IAtlTexture_h
#define IAtlTexture_h

// Basic class.
#ifndef AtlTypes_h
	#include "CATL/AvAtlTypes.h"
#endif
#ifndef CAtlVector_h
	#include "CATL/CAtlVector.h"
#endif
#ifndef CAtlColor_h
	#include "CATL/CAtlColor.h"
#endif

namespace  AvAtl {


/// Interface for texture.
/** \interface IAtlTexture 
 *	Class that contains the information on a texture
 *
 * \author Abvent R&D Copyright (c) 2002
 * \author Richard Young
 * \version 1.0
 * \date 04/02/2002
 */
class IAtlTexture
{
public:
	/// Return the url of the image.
	virtual tURL					getURL() const = 0;
	/// Set the url of the image.
	virtual void					setURL(tURL inURL) = 0;

	/// Return the origin.
	virtual const CAtlVector&	getOrigin() const = 0;
	/// Set the origin.
	virtual void					setOrigin(const CAtlVector& inOrigin) = 0;

	/// Return the X reference axis.
	virtual const CAtlVector&	getXRefAxis() const = 0;
	/// Set the X reference axis.
	virtual void					setXRefAxis(const CAtlVector& inAxis) = 0;

	/// Return the Y reference axis.
	virtual const CAtlVector&	getYRefAxis() const = 0;
	/// Set the Y reference axis.
	virtual void					setYRefAxis(const CAtlVector& inAxis) = 0;

	/// Return the width.
	virtual double					getWidth() const = 0;
	/// Set the width.
	virtual void					setWidth(double inWidth) = 0;

	/// Return the height.
	virtual double					getHeight() const = 0;
	/// Set the height.
	virtual void					setHeight(double inHeight) = 0;

	/// Return true if the first cutout color is used.
	virtual bool					getCutout1Flag() const = 0;
	/// Set the first cutout color usage.
	virtual void					setCutout1Flag(bool inFlag) = 0;

	/// Return the first cutout color.
	virtual const CAtlColor&	getCutoutColor1() const = 0;
	/// Set the first cutout color.
	virtual void					setCutoutColor1(const CAtlColor& inColor) = 0;

	/// Return true if the second cutout color is used.
	virtual bool					getCutout2Flag() const = 0;
	/// Set the second cutout color usage.
	virtual void					setCutout2Flag(bool inFlag) = 0;

	/// Return the second cutout color.
	virtual const CAtlColor&	getCutoutColor2() const = 0;
	/// Set the second cutout color.
	virtual void					setCutoutColor2(const CAtlColor& inColor) = 0;

	/// Return true if the cutset is used.
	virtual bool					getCutSetFlag() const = 0;
	/// Set the cutset usage.
	virtual void					setCutSetFlag(bool inFlag) = 0;
};

} // namespace AvAtl

#endif
