/** \file
 * Header for the interface IAtlViewOpt
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 1.0
 * \date 19/03/2003
 */

#ifndef IAtlViewOpt_h
#define IAtlViewOpt_h

// Basic class.
#ifndef IAtlRenderingOpt_h
	#include "CATL/IAtlRenderingOpt.h"
#endif
#ifndef IAtlCompressionOpt_h
	#include "CATL/IAtlCompressionOpt.h"
#endif


namespace  AvAtl {


/// Interface for all view options.
/** \interface IAtlViewOpt 
 *	Class that contains rendering and compressions options.
 *
 * \author Abvent R&D Copyright (c) 2003
 * \author Richard Young
 * \version 1.0
 * \date 19/03/2003
*/
class IAtlViewOpt
{
public:
	/// Get rendering options.
	virtual IAtlRenderingOpt*			getRenderingOpt() = 0;
	virtual const IAtlRenderingOpt*		getRenderingOpt() const = 0;

	/// Get compressions options.
	virtual IAtlCompressionOpt*			getCompressionOpt() = 0;
	virtual const IAtlCompressionOpt*	getCompressionOpt() const = 0;

	/// Put an XML representation of the view options inside the father node.
	/** \retval the new node of the ambient.
	 \retval NULL if an error occurs. */
	virtual XMLNodeRef					putInXML(XMLNodeRef inFatherNode) const = 0;

	/// Initialize the view options with the XML.
	/** \retval true intialization from XML succeed.
	 \retval false an error occurs. */
	virtual bool						initWithXML(ConstXMLNodeRef inFatherNode) = 0;

protected:
	// You must not create or delete objects of this class.
	// This is the responsability of the CAtlMgr class.
										~IAtlViewOpt() {}
};


} // namespace AvAtl

#endif
