/**
 \file ICustomNode.h
 
 Interface class for custom TCE node.
 
 \verbatim
 
 File			:	ICustomNode.h
 Author			:	Richard Young
 Creation date	:	28/04/2001
 Description	:	The interface ICustomNode is the class for non Artlantis node in tce tree.

 Modifications	:

 \endverbatim
 */


#ifndef ICustomNode_h
#define ICustomNode_h


#ifndef AtlTypes_h
	#include "CATL/AvAtlTypes.h"
#endif


namespace AvAtl{


// Forward declarations.
class ITCENode;


/// The interface ICustomNode is the class for non Artlantis node in tce tree
/** \interface ICustomNode
 *
 * \author Abvent R&D Copyright (c) 2001
 * \author Richard Young
 * \version 1.0
 * \date 28/04/2001
 */
class ICustomNode
{
public:
	// For ATL library internal usage only.
#ifdef ITCENode_h
	enum { mType = ITCENode::eCustomNode };
#endif

	/// Return the node of this custom node.
	virtual const ITCENode*		asNode() const = 0;
	virtual ITCENode*			asNode() = 0;

	/// Initialize with the XML data.
	//virtual bool				initWithXML(ConstXMLNodeRef inXML) = 0;

	/// Get the custom node class
	virtual tUtf8				getClass() const = 0;

	/// Set the custom node class
	virtual void				setClass(tUtf8 inClassName) = 0;

	/// Get a non modifiable XML data of this node.
	virtual ConstXMLNodeRef		getXMLNodeRef() const = 0;

	/// Get a modifiable XML data of this node.
	virtual XMLNodeRef			getXMLNodeRef() = 0;

protected:
	/// Don't delete, use node refcount
								~ICustomNode() {};
};
	

// XML tag for the custom node data
#define TAG_CUSTOM_NODE_DATA		"Custom.Data"
	// XML tag for the class of custom node
	#define TAG_CUSTOM_NODE_CLASS		"Class"
	

} // namespace  AvAtl

#endif
