/**
 \file IGlazingNode.h
 
 Interface class for leaf TCE node.
 
 \verbatim
 
 File			:	IGlazingNode.h
 Author			:	Richard Young
 Creation date	:	28/04/2001
 Description	:	The interface IGlazingNode is the class for glazing node in tce tree.
 
 Modifications	:
 
 \endverbatim
 */


#ifndef IGlazingNode_h
#define IGlazingNode_h


namespace AvAtl{


// Forward declarations.
class ITCENode;


/// The interface IGlazingNode is the class for glazing node in tce tree
/** \interface IGlazingNode
 *
 * \author Abvent R&D Copyright (c) 2001
 * \author Richard Young
 * \version 1.0
 * \date 28/04/2001
 */
class IGlazingNode
{
public:
	// For ATL library internal usage only.
#ifdef ITCENode_h
	enum { mType = ITCENode::eGlazingNode };
#endif
	
	/// Return the node of this glazing node.
	virtual const ITCENode*		asNode() const = 0;
	virtual ITCENode*			asNode() = 0;
	
	/// The turbulence scale on X axis
	virtual double				getXScale() const = 0;
	virtual void				setXScale(double inXScale) = 0;
	
	/// The turbulence scale on Y axis
	virtual double				getYScale() const = 0;
	virtual void				setYScale(double inYScale) = 0;
	
	/// The amplitude of glass distortion
	virtual double				getFlatness() const = 0;
	virtual void				setFlatness(double inXScale) = 0;
	
	/// Control the auto detection of object center
	virtual bool				getTiltCenterDetect() const = 0;
	virtual void				setTiltCenterDetect(bool inDetect) = 0;
	
	/// The amplitude of tilting
	virtual double				getTiltFactor() const = 0;
	virtual void				setTiltFactor(double inFactor) = 0;

	/// Returns true if the animation is on.
	virtual bool				getActiveAnimationFlag() const = 0;
	/// Set the animation is on/off.
	virtual void				setActiveAnimationFlag(bool inValue) = 0;
	
	/// Returns the speed of the animation. Default value is 2.0
	virtual double				getSpeed() const = 0;
	/// Set the speed of the animation. 
	virtual void				setSpeed(double inValue) = 0;
	
	/// Set the current time of the animation (in seconds).
	virtual void				setTime(double inTime) = 0;
	virtual double				getTime() const = 0;

protected:
	/// Don't delete, use node refcount
								~IGlazingNode() {};
};


} // namespace  AvAtl

#endif
