#ifndef TAtlAutoPtr_h
#define TAtlAutoPtr_h


#include <stdexcept>


namespace AvAtl{


/// Template class for automatic pointer.
/** class X must have AddRef and Release methods. (Same as COM) */
template<class X>
class TAtlAutoPtr
{
public:
	/// Empty constructor
						TAtlAutoPtr()
						:	mPtr(NULL)
						{}

	/// Constructor with a standard ptr 
						TAtlAutoPtr(X* inPtr)
						:	mPtr(inPtr)
						{
							if (mPtr)
								mPtr->AddRef();
						}

	/// Constructor with another smart ptr
						TAtlAutoPtr(const TAtlAutoPtr& inOther)
						:	mPtr(inOther.mPtr)
						{
							if (mPtr)
								mPtr->AddRef();
						}

	/// Destructor
						~TAtlAutoPtr()
						{
							if (mPtr)
								mPtr->Release();
						}

	/// Assignement operator
	TAtlAutoPtr&		operator=(const TAtlAutoPtr& inOther)
						{
							if (inOther.mPtr)
								inOther.mPtr->AddRef();
							if (mPtr)
								mPtr->Release();
							mPtr = inOther.mPtr;
							return *this;
						}

	/// Test for non null ptr
						operator bool() const { return mPtr != NULL; }

	/// Test for null ptr
	bool				operator !() const { return mPtr == NULL; }

	/// Test for equality
	bool				operator==(const TAtlAutoPtr& inOther) const
						{
							return mPtr == inOther.mPtr;
						}

	/// Test for difference
	bool				operator!=(const TAtlAutoPtr& inOther) const
						{
							return mPtr != inOther.mPtr;
						}

	/// Auto convertion to a standard pointer.
						operator X*() const
						{
							return mPtr;
						}

	/// Arrow operator
	X*					operator->() const
						{
							validate();
							return mPtr;
						}

	/// Star operator
	X&					operator*() const
						{
							validate();
							return *mPtr;
						}

private:
	/// Validate that the ptr isn't NULL.
	void				validate() const
						{
							if (mPtr == NULL)
								throw std::runtime_error("Dereferencing a null ptr");
						}

	/// The standard pointer
	X*					mPtr;
};


} // namespace  AvAtl

#endif
